@@ -35,11 +35,15 @@ taxsub <- file.path(pth, "test_subset_taxa.nex")
 ## NEXUS file to test for underscores
 tr_under <- file.path(pth, "test_underscores.nex")
 
+## NEXUS file with no tree block
+tr_empty <- file.path(pth, "test_empty.nex")
+
 stopifnot(file.exists(co1File))
 stopifnot(file.exists(multiLinesFile))
 stopifnot(file.exists(taxsub))
 stopifnot(file.exists(treeDiscDt))
 stopifnot(file.exists(tr_under))
+stopifnot(file.exists(tr_empty))
 
 ## function (file, simplify=TRUE, type=c("all", "tree", "data"),
 ##   char.all=FALSE, polymorphic.convert=TRUE, levels.uniform=TRUE,
@@ -183,8 +187,28 @@ test_that("missing_edge_length is a single numeric value", {
 context("Tree with subset of taxa listed in TAXA block")
 
 test_that("taxa subset", {
-              expect_error(tr <- read_nexus_phylo(file = taxsub),
-                           "All the taxa listed")
+              tr <- read_nexus_phylo(file = taxsub)
+              ncl <- rncl(file = taxsub, file.format = "nexus")
+              expect_equal(ncl$trees[1], "(2,((3,1),(5,4)))")
+              expect_equal(ncl$trees[2], "(2:6,((3:2,1:1):4,(5:10,4:9):7):3)")
+              expect_equal(ncl$trees[3], "(2,(3,(6,(5,4))))")
+              expect_equal(ncl$trees[4], "(5,(4,(2,(3,(1,6)))))")
+              expect_equal(tr[[1]]$edge, cbind(c(6, 8, 8, 9, 9, 6, 7, 7),
+                                               (1:9)[-6]))
+              expect_equal(tr[[2]]$edge, cbind(c(6, 8, 8, 9, 9, 6, 7, 7),
+                                               (1:9)[-6]))
+              expect_equal(tr[[3]]$edge, cbind(c(6, 7, 8, 9, 9, 6, 7, 8),
+                                               (1:9)[-6]))
+              expect_equal(tr[[4]]$edge, cbind(c(7, 8, 9, 10, 11, 11, 7, 8, 9, 10),
+                                               (1:11)[-7]))
+              expect_equal(tr[[2]]$edge.length,
+                           c(6, 2, 1, 10, 9, 3, 4, 7))
+              expect_equal(tr[[1]]$edge.length, NULL)
+              expect_equal(tr[[1]]$tip.label, c("porifera", "ctenophora", "cnidaria", "deuterostomia", "protostomia"))
+              expect_equal(tr[[2]]$tip.label, c("porifera", "ctenophora", "cnidaria", "deuterostomia", "protostomia"))
+              expect_equal(tr[[3]]$tip.label, c("porifera", "ctenophora", "xeno", "deuterostomia", "protostomia"))
+              expect_equal(tr[[4]]$tip.label, c("deuterostomia", "protostomia", "porifera", "ctenophora", "cnidaria", "xeno"))
+              expect_equal(names(tr), paste0("hyp", 1:4))
           })
 
 ############################################################################
@@ -221,3 +245,23 @@ test_that("spacesAsUnderscores is FALSE",  {
               expect_false(any(grepl("_", ncl$charLabels)))
               expect_false(any(grepl("_", ncl$stateLabels)))
           })
+
+############################################################################
+## Test on non - existing file                                            ##
+############################################################################
+
+context("non existing file")
+
+test_that("non existing file",
+          expect_error(rncl(file = "foo"), "doesn't exist")
+          )
+
+############################################################################
+## Test on an empty file                                                  ##
+############################################################################
+
+context("test on empty file")
+
+test_that("empty file (no trees)",
+          expect_equal(read_nexus_phylo(file = tr_empty),
+                       NULL))
